/*
    24 bit Device Independent Bitmap class, 32 bit for BeOS
    
    Copyright (c) 2002,2003 Alessandro Scotti
    Modified for BeOS (2004) Carwyn Jones
    http://www.ascotti.org/

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <assert.h>

#include "dib24_beos.h"

void Dib24::createBitmap( int width, int height )
{
    assert( width > 0 );
    assert( height > 0 );

	hdc_ = new BBitmap(BRect(0, 0, width - 1, height - 1), B_RGB32);
	assert( hdc_ != 0 );
	
    bitmapbits_ = (uint8 *)hdc_->Bits();
    scanlength_ = hdc_->BytesPerRow(); // Length of a scan line 
    width_ = width;
    height_ = height;
}

Dib24::Dib24( int width, int height )
{
    createBitmap( width, height );
    clear();
}

Dib24::Dib24( const Dib24 & dib )
{
    createBitmap( dib.width_, dib.height_ );
    memcpy( bitmapbits_, dib.bitmapbits_, scanlength_*height_ );
}

Dib24::~Dib24()
{
    delete hdc_;
}

void Dib24::clear()
{
    memset(bitmapbits_, 0, scanlength_*height_ );
}

void Dib24::stretch( BBitmap *hdc, int x, int y, int width, int height )
{
}

uint32 Dib24::getPixel( int x, int y )
{
    if( x < 0 || x >= width_ || y < 0 || y >= height_ )
        return 0;

    return getFastPixel( x, y );
}

void Dib24::setPixel( int x, int y, uint32 value )
{
    if( x < 0 || x >= width_ || y < 0 || y >= height_ )
        return;

    setFastPixel( x, y, value );
}
